//*
//
//# Менеджер расширений
//
//Реализует функционал по координации расширений в системе и служит единой точкой доступа для работы с расширениями:
//- Регистрирует все расширения в едином реестре
//- Предоставляет доступ к реестру расширений на получение доступных расширений в системе
//- Контролирует процесс установки расширения, устанавливает все необходимые зависимости в правильном порядке
//- Контролирует создание системной коллекции `system_extensions` (System/Extensions) и создание/удалений в ней установленных расширений
//- Контролирует создание системной коллекции `system_actions` (System/Actions). Выполняет удаление всех действий связанных
//с расширением при его удалении.
//- Выполняет переадресацию запросов на действия для расширений
//
//Менеджер расширений для контроля установленных расширений использует системные коллекции. При обращении к сервису контента
//используются системный уровень прав для создания необходимых коллекций и получения данных:
//1. `system_extensions` (System Extensions) - доступна только системным пользователям
//2. `system_actions` (System Actions) - по умолчанию доступна только системным пользователям, настройки доступа на чтение
//выдаются пользователям вручную. В зависимости от пользователя в интерфейсе отображаются те или иные доступные действия.
//
//Проверка наличия коллекций и создание в случае их отсутствия выполняется в момент установки расширений. После установки
//расширения в коллекцию `system_extensions` добавляется запись об установленном расширении. Действия добавляются в
//коллекцию `system_actions` расширениями по собственному усмотрению при установке.
//
//Для обращения к расширениям используются права текущего пользователя запрашивающего операцию. Если пользователь не
//обладает необходимыми правами для выполнения действия то операция вернет ошибку.
//

// Code generated by protoc-gen-go-grpc. DO NOT EDIT.
// versions:
// - protoc-gen-go-grpc v1.3.0
// - protoc             v3.21.12
// source: extensions/manager.proto

package extensions

import (
	context "context"
	grpc "google.golang.org/grpc"
	codes "google.golang.org/grpc/codes"
	status "google.golang.org/grpc/status"
)

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
// Requires gRPC-Go v1.32.0 or later.
const _ = grpc.SupportPackageIsVersion7

const (
	ExtensionManager_RegisterExtensions_FullMethodName   = "/extensions.ExtensionManager/RegisterExtensions"
	ExtensionManager_UnregisterExtensions_FullMethodName = "/extensions.ExtensionManager/UnregisterExtensions"
	ExtensionManager_ListExtensions_FullMethodName       = "/extensions.ExtensionManager/ListExtensions"
)

// ExtensionManagerClient is the client API for ExtensionManager service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
type ExtensionManagerClient interface {
	// ##  Регистрация расширений
	//
	// Регистрация\Дерегистрация происходить через сервис менеджера расширений (Extension Manager). В процессе регистрации сервис сообщает
	// о поддерживаемых сервисом действиях (Actions) и версии сервиса и зависимостях:
	// 1. Действия (Actions) - перечень действия которые обрабатываются сервисом. Включает в себя как системные действия,
	// так и пользовательские, которые могут быть использованы в интерфейсе;
	// 2. Имя сервиса/расширения - название сервиса внутри системы;
	// 3. Версия сервиса - сервис сообщает текущую версию сервиса. Контроллер сообщает пользователю о возможности обновления
	// расширения при смене версии;
	// 4. Описание версии - содержит информацию об изменениях в последних версиях расширения;
	// 5. Зависимости - перечень расширений которые необходимы сервису для функционирования. При установке сервиса
	// все расширения от которых он зависит, будут так же установлены.
	RegisterExtensions(ctx context.Context, in *RegisterExtensionsRequest, opts ...grpc.CallOption) (*RegisterExtensionsResponse, error)
	UnregisterExtensions(ctx context.Context, in *UnregisterExtensionsRequest, opts ...grpc.CallOption) (*UnregisterExtensionsResponse, error)
	// Получить список зарегистрированных сервисов
	ListExtensions(ctx context.Context, in *ListExtensionsRequest, opts ...grpc.CallOption) (*ListExtensionsResponse, error)
}

type extensionManagerClient struct {
	cc grpc.ClientConnInterface
}

func NewExtensionManagerClient(cc grpc.ClientConnInterface) ExtensionManagerClient {
	return &extensionManagerClient{cc}
}

func (c *extensionManagerClient) RegisterExtensions(ctx context.Context, in *RegisterExtensionsRequest, opts ...grpc.CallOption) (*RegisterExtensionsResponse, error) {
	out := new(RegisterExtensionsResponse)
	err := c.cc.Invoke(ctx, ExtensionManager_RegisterExtensions_FullMethodName, in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *extensionManagerClient) UnregisterExtensions(ctx context.Context, in *UnregisterExtensionsRequest, opts ...grpc.CallOption) (*UnregisterExtensionsResponse, error) {
	out := new(UnregisterExtensionsResponse)
	err := c.cc.Invoke(ctx, ExtensionManager_UnregisterExtensions_FullMethodName, in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *extensionManagerClient) ListExtensions(ctx context.Context, in *ListExtensionsRequest, opts ...grpc.CallOption) (*ListExtensionsResponse, error) {
	out := new(ListExtensionsResponse)
	err := c.cc.Invoke(ctx, ExtensionManager_ListExtensions_FullMethodName, in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// ExtensionManagerServer is the server API for ExtensionManager service.
// All implementations must embed UnimplementedExtensionManagerServer
// for forward compatibility
type ExtensionManagerServer interface {
	// ##  Регистрация расширений
	//
	// Регистрация\Дерегистрация происходить через сервис менеджера расширений (Extension Manager). В процессе регистрации сервис сообщает
	// о поддерживаемых сервисом действиях (Actions) и версии сервиса и зависимостях:
	// 1. Действия (Actions) - перечень действия которые обрабатываются сервисом. Включает в себя как системные действия,
	// так и пользовательские, которые могут быть использованы в интерфейсе;
	// 2. Имя сервиса/расширения - название сервиса внутри системы;
	// 3. Версия сервиса - сервис сообщает текущую версию сервиса. Контроллер сообщает пользователю о возможности обновления
	// расширения при смене версии;
	// 4. Описание версии - содержит информацию об изменениях в последних версиях расширения;
	// 5. Зависимости - перечень расширений которые необходимы сервису для функционирования. При установке сервиса
	// все расширения от которых он зависит, будут так же установлены.
	RegisterExtensions(context.Context, *RegisterExtensionsRequest) (*RegisterExtensionsResponse, error)
	UnregisterExtensions(context.Context, *UnregisterExtensionsRequest) (*UnregisterExtensionsResponse, error)
	// Получить список зарегистрированных сервисов
	ListExtensions(context.Context, *ListExtensionsRequest) (*ListExtensionsResponse, error)
	mustEmbedUnimplementedExtensionManagerServer()
}

// UnimplementedExtensionManagerServer must be embedded to have forward compatible implementations.
type UnimplementedExtensionManagerServer struct {
}

func (UnimplementedExtensionManagerServer) RegisterExtensions(context.Context, *RegisterExtensionsRequest) (*RegisterExtensionsResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method RegisterExtensions not implemented")
}
func (UnimplementedExtensionManagerServer) UnregisterExtensions(context.Context, *UnregisterExtensionsRequest) (*UnregisterExtensionsResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method UnregisterExtensions not implemented")
}
func (UnimplementedExtensionManagerServer) ListExtensions(context.Context, *ListExtensionsRequest) (*ListExtensionsResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method ListExtensions not implemented")
}
func (UnimplementedExtensionManagerServer) mustEmbedUnimplementedExtensionManagerServer() {}

// UnsafeExtensionManagerServer may be embedded to opt out of forward compatibility for this service.
// Use of this interface is not recommended, as added methods to ExtensionManagerServer will
// result in compilation errors.
type UnsafeExtensionManagerServer interface {
	mustEmbedUnimplementedExtensionManagerServer()
}

func RegisterExtensionManagerServer(s grpc.ServiceRegistrar, srv ExtensionManagerServer) {
	s.RegisterService(&ExtensionManager_ServiceDesc, srv)
}

func _ExtensionManager_RegisterExtensions_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(RegisterExtensionsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ExtensionManagerServer).RegisterExtensions(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: ExtensionManager_RegisterExtensions_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ExtensionManagerServer).RegisterExtensions(ctx, req.(*RegisterExtensionsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ExtensionManager_UnregisterExtensions_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(UnregisterExtensionsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ExtensionManagerServer).UnregisterExtensions(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: ExtensionManager_UnregisterExtensions_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ExtensionManagerServer).UnregisterExtensions(ctx, req.(*UnregisterExtensionsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _ExtensionManager_ListExtensions_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListExtensionsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ExtensionManagerServer).ListExtensions(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: ExtensionManager_ListExtensions_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ExtensionManagerServer).ListExtensions(ctx, req.(*ListExtensionsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

// ExtensionManager_ServiceDesc is the grpc.ServiceDesc for ExtensionManager service.
// It's only intended for direct use with grpc.RegisterService,
// and not to be introspected or modified (even as a copy)
var ExtensionManager_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "extensions.ExtensionManager",
	HandlerType: (*ExtensionManagerServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "RegisterExtensions",
			Handler:    _ExtensionManager_RegisterExtensions_Handler,
		},
		{
			MethodName: "UnregisterExtensions",
			Handler:    _ExtensionManager_UnregisterExtensions_Handler,
		},
		{
			MethodName: "ListExtensions",
			Handler:    _ExtensionManager_ListExtensions_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "extensions/manager.proto",
}
